-- workout
-- Table for Workout Entity
-- 6_workout_create_table.sql
CREATE TABLE workout_entity (
        _id INTEGER PRIMARY KEY AUTOINCREMENT, -- 0
        remote_id TEXT,

        name TEXT,
        start_datetime INTEGER,
        start_locale_timezone TEXT, -- 4
        created_datetime INTEGER,
        updated_datetime INTEGER,
        reference_key TEXT,
        source TEXT,
        notes TEXT, -- 9

        -- Aggregates
        distance_total REAL,
        metabolic_energy_total REAL,
        active_time_total REAL,
        elapsed_time_total REAL,
        steps_total REAL, -- 14

        heartrate_min REAL,
        heartrate_max REAL,
        heartrate_avg REAL,

        speed_min REAL,
        speed_max REAL, -- 19
        speed_avg REAL,

        cadence_min REAL,
        cadence_max REAL,
        cadence_avg REAL,

        power_min REAL, -- 24
        power_max REAL,
        power_avg REAL,

        -- Documentation deliberately removed
        -- but data still in responses
        torque_min REAL,
        torque_max REAL,
        torque_avg REAL, -- 29

        has_time_series BOOLEAN,

        -- Undocumented at time of schema creation
        willpower REAL,
        is_verified BOOLEAN,
        facebook BOOLEAN,
        twitter BOOLEAN, -- 34

        stride_length_min REAL,
        stride_length_max REAL,
        stride_length_avg REAL,
        is_default_name BOOLEAN, -- 38
        contexts TEXT,
        foot_strike_angle_avg REAL,
        ground_contact_time_avg REAL,
        coaching_eligibility BOOLEAN, --42
        coaching_ineligibility_reasons TEXT
);
CREATE UNIQUE INDEX idx_workout_entity_remote_id ON workout_entity(remote_id);

-- Child table for Workout Entity for Insights
CREATE TABLE workout_insights(
        _id INTEGER PRIMARY KEY AUTOINCREMENT,

        insight_id TEXT,
        insight_data_type_id TEXT,
        insight_target_min REAL,
        insight_target_max REAL,
        insight_field TEXT,

        entity_id INTEGER, -- 7

        FOREIGN KEY(entity_id) REFERENCES workout_entity(_id) ON DELETE CASCADE
);
CREATE INDEX workout_insights_entity_id ON workout_insights(entity_id);